@@ -1,6 +1,8 @@
 import csv
 import shelve
 import re
+import dbm.gnu
+import pickle
 from qualys_etl.etld_lib import etld_lib_config as etld_lib_config
 from qualys_etl.etld_lib import etld_lib_functions as etld_lib_functions
 global count_host_ids_written
@@ -47,12 +49,13 @@ def asset_inventory_to_csv():  # Create CSV File from Shelve Database
             writer = csv.DictWriter(csvfile, fieldnames=csv_columns, quoting=csv.QUOTE_ALL)
             writer.writeheader()
             csv_row = csv_headers.copy()
-            # Iterate through Shelve Database
+            # Iterate through Shelve Database using dbm.gnu.open for speed.
             etld_lib_functions.logger.info(f"shelve db filename: {str(etld_lib_config.asset_inventory_shelve_file)}")
-            with shelve.open(str(etld_lib_config.asset_inventory_shelve_file), flag='r') as shelve_database:
-                etld_lib_functions.logger.info(f"shelve db count: {len(shelve_database)}")
-                for shelve_database_item in shelve_database:
-                    asset_inventory_item = shelve_database[shelve_database_item]
+            with dbm.gnu.open(str(etld_lib_config.asset_inventory_shelve_file), 'rf') as shelve_database:
+                #etld_lib_functions.logger.info(f"shelve db count: {len(shelve_database)}")
+                shelve_database_item = shelve_database.firstkey()
+                while shelve_database_item is not None:
+                    asset_inventory_item = pickle.loads(shelve_database[shelve_database_item])
                     truncated_field_list = ""
                     for csv_column in csv_columns:  # Iterate through expected columns (contract)
                         if csv_column in asset_inventory_item.keys():  # Iterate through columns found in Shelve
@@ -74,11 +77,12 @@ def asset_inventory_to_csv():  # Create CSV File from Shelve Database
 
                     count_host_ids_written = count_host_ids_written + 1
                     count_host_ids_written_display_progress = count_host_ids_written_display_progress + 1
-                    if count_host_ids_written_display_progress > 1999:
+                    if count_host_ids_written_display_progress > 9999:
                         count_host_ids_written_display_progress = 0
                         etld_lib_functions.logger.info(f"csv rows written: {count_host_ids_written}")
 
                     csv_row = csv_headers.copy()
+                    shelve_database_item = shelve_database.nextkey(shelve_database_item)
 
     except Exception as e:
         etld_lib_functions.logger.error(f"Error writing to file: {str(asset_inventory_csv_file)}, please retry after fixing error")
