@@ -173,12 +173,12 @@ def extract_validation(validation_type='xml', output_file_to_validate=None):
 
 
 def extract_qualys(
-        try_extract_max_count=3,
+        try_extract_max_count=30,
         url=None,
         headers=None,
         payload=None,
-        http_conn_timeout=30,
-        chunk_size_calc=20480,
+        http_conn_timeout=300,
+        chunk_size_calc=10240,
         output_file=None,
         cred_dict=None,
         qualys_headers_dict=None,
@@ -201,7 +201,7 @@ def extract_qualys(
                     with open(output_file, "wb") as f:
                         for chunk in r.iter_content(chunk_size=chunk_size_calc):
                             try:
-                                 f.write(chunk)
+                                f.write(chunk)
                             except Exception as e:
                                 f.write(etld_lib_functions.remove_low_high_values(chunk).decode('utf-8'))
                     extract_validation(validation_type=extract_validation_type, output_file_to_validate=output_file)
@@ -215,11 +215,11 @@ def extract_qualys(
                     etld_lib_functions.logger.error(f"HTTP {r.status_code}, exiting. message={message}")
                     exit(1)
         except Exception as e:
-            time_sleep = 120
+            time_sleep = 300
             etld_lib_functions.logger.warning(f"Warning for extract file: {Path(output_file).name}")
             etld_lib_functions.logger.warning(f"Warning {e}")
             etld_lib_functions.logger.warning(f"Sleeping for {time_sleep} seconds before next retry.")
-            etld_lib_functions.logger.warning(f"Retry attempt number: {_ + 1}")
+            etld_lib_functions.logger.warning(f"Retry attempt number: {_ + 1} of max retry: {try_extract_max_count}")
             time.sleep(time_sleep)
             continue
         else:
