@@ -157,7 +157,7 @@ def host_list_detection_qid_csv_columns():  # Return list of csv columns
     return csv_columns
 
 
-def asset_inventory_csv_columns():  # Return list of csv columns
+def asset_inventory_csv_columns():  # Return list of csv columns updated 0.6.111
 
     csv_columns = [
         'assetId', 'assetUUID', 'hostId', 'lastModifiedDate', 'agentId', 'createdDate', 'sensorLastUpdatedDate',
@@ -167,7 +167,8 @@ def asset_inventory_csv_columns():  # Return list of csv columns
         'totalMemory', 'cpuCount', 'lastLoggedOnUser', 'hwUUID', 'biosSerialNumber', 'biosAssetTag', 'isContainerHost',
         'operatingSystem', 'hardware', 'userAccountListData', 'openPortListData', 'volumeListData',
         'networkInterfaceListData', 'softwareListData', 'provider', 'cloudProvider', 'agent', 'sensor', 'container',
-        'inventory', 'activity', 'tagList', 'serviceList', 'lastLocation', 'processor', 'TRUNCATED_FIELD_LIST'
+        'inventory', 'activity', 'tagList', 'serviceList', 'lastLocation', 'processor', 'criticality',
+        'businessInformation', 'assignedLocation', 'businessAppListData', 'TRUNCATED_FIELD_LIST'
                    ]
     return csv_columns
 
