@@ -69,7 +69,8 @@ def update_api_fqdn_server(cred):
 
 def update_gateway_fqdn_server(cred):
     if cred.get('api_fqdn_server') in etld_lib_credentials.platform_url.keys():
-        cred['gateway_fqdn_server'] = etld_lib_credentials.platform_url.get(cred.get('gateway_fqdn_server'))
+        cred['gateway_fqdn_server'] = etld_lib_credentials.platform_url.get(cred.get('api_fqdn_server'))
+
     print(f"Current gateway_fqdn_server: {cred.get('gateway_fqdn_server')}")
     response = input(f"Update gateway_fqdn_server? ( yes or no ): ")
     if response in 'yes':
@@ -122,6 +123,7 @@ def if_update_credentials(first_time=False):
         credentials = etld_lib_credentials.get_cred()
         update_username(credentials)
         update_api_fqdn_server(credentials)
+        update_gateway_fqdn_server(credentials)
         update_password(credentials)
         old_cred = etld_lib_credentials.get_cred()
         if old_cred == credentials:
